C$Procedure      RAYBOX ( test for intersection of ray with voxel box )
 
      SUBROUTINE RAYBOX (OBS, RAY, BBLIM, FOUND, NEAR, FAR)
 
C$ Abstract
C
C     Determine if a ray projected from a given point intersects
C     a rectangular box.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     RAY
C
C$ Declarations
 
      IMPLICIT              NONE
 
      LOGICAL               FOUND
 
      DOUBLE PRECISION      FAR    ( 3 )
      DOUBLE PRECISION      OBS    ( 3 )
      DOUBLE PRECISION      RAY    ( 3 )
      DOUBLE PRECISION      NEAR   ( 3 )
      DOUBLE PRECISION      BBLIM  ( 2, 3 )
 
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OBS        I   Coordinates of observer in the model frame.
C     RAY        I   Direction observer is looking.
C     BBLIM      I   X, Y and Z limits of bounding box.
C     FOUND      O   TRUE if an intersection was found between the
C                    ray and the bounding box.
C     NEAR       O   Coordinates of the first intersection point.
C     FAR        O   Coordinates of the second intersection point.
C
C$ Detailed_Input
C
C     OBS        Coordinates of observer in the model frame.
C
C     RAY        Direction observer is looking.
C
C     BBLIM      X, Y and Z limits of bounding box.
C
C$ Detailed_Output
C
C     FOUND      .TRUE. if an intersection was found between the
C                ray and the bounding box.
C
C     NEAR       Coordinates of the first intersection point.
C
C     FAR        Coordinates of the second intersection point.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C     1)
C
C$ Particulars
C
C     Box intersection determination,
C     using Kay and Kayjia's "slab" method.
C
C$ Examples
C
C     TBD
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 05-MAY-1999 (JAB)
C
C-&
 
C$ Index_Entries
C
C     We need a permuted index entry
C
C-&
 
 
      INTEGER               I
 
      DOUBLE PRECISION      D
      DOUBLE PRECISION      L
      DOUBLE PRECISION      H
      DOUBLE PRECISION      P
      DOUBLE PRECISION      T1
      DOUBLE PRECISION      T2
      DOUBLE PRECISION      TMP
      DOUBLE PRECISION      TFAR
      DOUBLE PRECISION      TNEAR
 
 
      FOUND = .FALSE.
 
      TNEAR = -9.D9
      TFAR  =  9.D9
 
      DO I = 1, 3
         FAR(I)  = -9.D9
         NEAR(I) = -9.D0
      END DO
 
C
C     Compute intersections with planes.
C
 
      TFAR  =  9.D9
      TNEAR = -9.D9
 
      DO I = 1, 3
 
         D = RAY(I)
         P = OBS(I)
         L = BBLIM(1,I)
         H = BBLIM(2,I)
 
         IF ( D .NE. 0.D0 ) THEN
            T1 = (L-P) / D
            T2 = (H-P) / D
         ELSE
            IF ( (P.LT.L) .OR. (P.GT.H) ) THEN
               WRITE(*,*) 'return 1, p,l,h = ', P, L, H 
				   RETURN
				END IF
         END IF
 
         IF ( T1 .GT. T2 ) THEN
            TMP = T2
            T2  = T1
            T1  = TMP
         END IF
 
         IF ( T1 .GT. TNEAR ) TNEAR = T1
         IF ( T2 .LT. TFAR  ) TFAR  = T2
 
      END DO
 
 
      DO I = 1, 3
         NEAR(I) = OBS(I) + TNEAR*RAY(I)
         FAR(I)  = OBS(I) + TFAR*RAY(I)
      END DO
 
      IF ( TNEAR .GT. TFAR ) THEN
         WRITE(*,*) 'return 2, tnear, tfar = ', TNEAR, TFAR
         FOUND = .FALSE.
         RETURN
      END IF
 
      IF ( TFAR .LT. 0.D0 ) THEN
         WRITE(*,*) 'return 3, tnear, tfar = ', TNEAR, TFAR
         FOUND = .FALSE.
         RETURN
      END IF
 
      WRITE(*,*) 'return 4, tnear, tfar = ', TNEAR, TFAR
 
      FOUND = .TRUE.
 
 
      RETURN
 
      END
