C$Procedure  TRAZEL  ( maximum possible apparent elevation of a plate )
 
      SUBROUTINE TRAZEL ( AVERT, ANORM, BVERT, ABOVE, MAXELE )
 
C$ Abstract
C
C     Given two plates, determine the maximum elevation
C     (angle from the horizontal) of the second plate (plate-B) as
C     seen from the first (plate-A).
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     PLATE
C
C$ Declarations
 
      IMPLICIT              NONE
 
      LOGICAL               ABOVE     ( 3 )
 
      DOUBLE PRECISION      MAXELE
      DOUBLE PRECISION      ANORM     ( 3 )
      DOUBLE PRECISION      AVERT     ( 3, 3 )
      DOUBLE PRECISION      BVERT     ( 3, 3 )
 
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     AVERT      I   Coordinates of plate-A's vertices.
C     ANORM      I   Components of plate-A's normal vector.
C     BVERT      I   Coordinates of plate-B's vertices.
C     ABOVE      I   .TRUE. if a plate-B vertex is visible from
C                    plate-A, .FALSE. if not.
C     MAXELE     O   Maximum elevation of plate-B as observed
C                    from plate-A.
C
C$ Detailed_Input
C
C     AVERT      Coordinates of plate-A's vertices.
C     ANORM      Components of base plate's normal vector.
C     BVERT      Coordinates of plate-B's vertices.
C     ABOVE      .TRUE. if a plate-B vertex is visible from
C                plate-A, .FALSE. if not.
C
C$ Detailed_Output
C
C     MAXELE     Maximum elevation of plate-B as observed
C                from plate-A.
C
C$ Parameters
C
C     None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free.
C
C$ Particulars
C
C     Later
C
C$ Examples
C
C     Later
C
C$ Restrictions
C
C     None.
C
C$ Author_and_Institution
C
C     J.A. Bytof      (JPL)
C
C$ Literature_References
C
C     None.
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 22-MAR-1999 (JAB)
C
C
C-&
 
C$ Index_Entries
C
C     plate
C
C-&
 
      INTEGER               I
      INTEGER               J
      INTEGER               K
 
      DOUBLE PRECISION      ELEV
      DOUBLE PRECISION      CLEN
      DOUBLE PRECISION      A       ( 3 )
      DOUBLE PRECISION      B       ( 3 )
      DOUBLE PRECISION      C       ( 3 )
      DOUBLE PRECISION      P       ( 3 )
 
 
 
      MAXELE = -99999.D0
 
C
C     Loop over plate-B vertices to find the
C     line of sight that results in the maximum observed elevation
C     as seen from plate-A.
C
 
      DO I = 1, 3
 
         IF ( ABOVE(I) ) THEN
 
C
C     P is a visible vertex of plate-B.
C
 
            CALL VEQU ( BVERT(1,I), P )
 
C
C     Loop over the three sides of plate-A.
C
 
            DO J = 1, 3
 
C
C
C      Generate a baseline segment of plate-A.
C
 
               K = 1 + MOD( J, 3 )
 
               CALL VEQU ( AVERT(1,J), A )
               CALL VEQU ( AVERT(1,K), B )
 
C
C      What point on line AB is closest to P?
C
 
               CALL PINSEG ( A, B, P, C, CLEN )
 
C
C      Closest point is "left" and outside segment AB.
C
 
               IF ( CLEN .LE. 0.D0 ) THEN
 
                  MAXELE = DMAX1( MAXELE, ELEV( ANORM, A, P ) )
 
C
C      Closest point is "right" and outside segment AB.
C
 
               ELSE IF ( CLEN .GE. 1.D0 ) THEN
 
                  MAXELE = DMAX1( MAXELE, ELEV( ANORM, B, P ) )
 
               ELSE
 
C
C      Closest point is inside segment AB.
C
                  MAXELE = DMAX1( MAXELE, ELEV( ANORM, C, P ) )
 
               END IF
 
            END DO
 
         END IF
 
      END DO
 
      RETURN
      END
